Intuitionistic Fuzzy Sets (IFS) library for Python
This library contains functions that calculate the distance, similarity and other kind of metrics 
between (Intuitionistic) Fuzzy Sets. 
Performance Indices are also contained in this library that calculate performance error, such as Accuracy, 
Precision, Recall and many others.
This library contains some applocations that use the different metrics included, for example to threshold 
images.